<template>
  <div class="app-container">

    <el-row>
      <el-col :span="8" v-for="(item, index) in contractList" :key="index" style="margin: 10px;width: 30%;">
        <el-card :body-style="{ padding: '0px' }">
          <el-image style="width: 420px;height: 187px;"
            :preview-src-list="['https://img2.baidu.com/it/u=68398439,1553004927&fm=253&fmt=auto&app=138&f=JPEG?w=800&h=357']"
            fit="cover" src="https://img2.baidu.com/it/u=68398439,1553004927&fm=253&fmt=auto&app=138&f=JPEG?w=800&h=357"
            class="image" />
          <div style="padding: 14px;">
            <span>{{ item.name }}</span>
            <span class="time" style="margin-left: 10px;">{{ item.unitName }}</span>
            <div class="bottom clearfix">
              <time class="time">{{ item.startTime }} — {{ item.endTime }}</time>
              <el-button type="text" class="button" @click="handleDetail(item)">查看详情</el-button>
            </div>
          </div>
        </el-card>
      </el-col>
    </el-row>

    <el-row :gutter="10" class="mb8" style="margin-top: 40px;">
      <el-col :span="1.5">
        <el-button type="primary" plain icon="el-icon-plus" size="mini" v-hasPermi="['system:contract:import']"
          @click="handleImport">新增</el-button>
      </el-col>
    </el-row>

    <!-- 合同详情 -->
    <el-dialog :title="detailName" :visible.sync="detail" width="800px" append-to-body>
      <el-form label-position="left" inline class="table-expand">
        <el-collapse v-model="activeNames">
          <el-collapse-item  v-for="(item, index) in ruleData" :key="index" :title="item.ruleName" :name="index">
            <div class="inline-input-container" v-for="(item, index) in item.children" :key="index">
              <b>{{ item.ruleDesc }}</b> <br v-if="item.ruleDesc"/>
              <el-tooltip class="item" v-for="(item, index) in item.children" :key="index" effect="dark" :content="item.deductCategory + ' ' + item.calcFraction + (item.calcUnit ? '/' + item.calcUnit : '')" placement="top">
                <span>{{ item.ruleCondition }}<br/></span>
                <!-- {{ item.deductCategory }} {{ item.calcFraction }}{{ item.calcUnit ? "/" + item.calcUnit : ''  }} -->
            </el-tooltip>
            </div>
          </el-collapse-item>
          <el-form-item label="合同附件" prop="attachment" class="top">
            <file-upload v-model="form.attachment"/>
          </el-form-item>
            <el-link class="top" v-for="item in contractInfo.attachment != null ? contractInfo.attachment.split(',') : contractInfo.attachment" :underline="false" :key="item" @click="handleDownload(item)">{{ item.substring(item.lastIndexOf("/") + 1) }}</el-link>
          <div style="text-align: right; margin-top: 10px;">
            <el-button type="primary" @click="submitForm">提交</el-button>
          </div>
        </el-collapse>
      </el-form>
    </el-dialog>

    <!-- 合同导入对话框 -->
    <el-dialog :title="upload.title" :visible.sync="upload.open" width="1000px" append-to-body>
      <el-form ref="form" :model="upload" :rules="rules" label-width="80px">
        <el-divider content-position="left">合同信息</el-divider>
        <div class="row-warp">
          <div class="row">
            <div class="row-left">
              <div class="block">
                <el-form-item label="合同名称" prop="name">
                  <el-input v-model="upload.name" />
                </el-form-item>
                <el-form-item label="公司名称" prop="unitId">
                  <el-select v-model="upload.unitId" placeholder="请选择">
                    <el-option v-for="item in unitList" :key="item.id" :label="item.value" :value="item.id">
                    </el-option>
                  </el-select>
                </el-form-item>
                <el-form-item label="合同时间" prop="timezone">
                  <el-date-picker :disabled="title === '修改合同时间'" @change="dateChange" v-model="upload.timezone"
                    value-format="yyyy-MM-dd HH:mm:ss" type="datetimerange" align="right" unlink-panels range-separator="至"
                    start-placeholder="开始时间" end-placeholder="结束时间">
                  </el-date-picker>
                </el-form-item>
              </div>
            </div>
            <div class="row-right" style="margin-left: 80px;">
              <div class="margin-5">
                <el-upload ref="upload" :limit="1" accept=".xlsx, .xls" :headers="upload.headers"
                  :action="upload.url + '?unitId=' + upload.unitId + '&startTime=' + upload.startTime + '&endTime=' + upload.endTime + '&name=' + upload.name"
                  :disabled="upload.isUploading" :on-progress="handleFileUploadProgress" :on-success="handleFileSuccess"
                  :file-list="upload.fileList"
                  :auto-upload="false" drag style="text-align: center;">
                  <i class="el-icon-upload"></i>
                  <div class="el-upload__text">将文件拖到此处，或<em>点击上传</em></div>
                  <div class="el-upload__tip text-center" slot="tip">
                    <span>仅允许导入xls、xlsx格式文件。</span>
                    <el-link type="primary" :underline="false" style="font-size:12px;vertical-align: baseline;"
                      @click="importTemplate">下载模板</el-link>
                  </div>
                </el-upload>
              </div>
            </div>
          </div>
        </div>
        <el-divider content-position="left">考核结果应用规则</el-divider>
        <div class="row-warp">
          <div class="row" v-for="(item, index) in upload.ruleList" :key="index">
            <div class="row-left" style="flex: 0.7;">
              <div class="block">
                <el-form-item label="考核条件" prop="ruleList">
                  <el-input v-model="item.scoreCondition" style="width: 250px;" />
                </el-form-item>
              </div>
            </div>
            <div class="row-right">
              <div class="margin-5">
                <el-form-item label="规则描述" prop="ruleList">
                  <el-input type="textarea" v-model="item.description" style="width: 300px;" />
                  <el-button style="margin-left: 50px;" type="danger" icon="el-icon-delete" circle @click="deleteRule(index)"></el-button>
                </el-form-item>
              </div>
            </div>
          </div>
        </div>
        <el-button style="margin-left: 50px;" type="success" icon="el-icon-plus" circle @click="addRule"></el-button>
    </el-form>

      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitFileForm">确 定</el-button>
        <el-button @click="upload.open = false">取 消</el-button>
      </div>
    </el-dialog>

  </div>
</template>

<script>
import { listContract, getContract, updateContract, addContract } from "@/api/platform/contract";
import { getRuleListByContractId } from "../../../api/platform/calculate-rule";
import { unitSelect } from "../../../api/platform/unit";
import { deptSelect } from "../../../api/system/dept";
import { getToken } from "@/utils/auth";

export default {
  name: "Contract",
  data() {
    return {
      contractInfo: {},
      // 合同导入参数
      upload: {
        // 是否显示弹出层（合同导入）
        open: false,
        // 弹出层标题（合同导入）
        title: "",
        // 是否禁用上传
        isUploading: false,
        // 设置上传的请求头部
        headers: { Authorization: "Bearer " + getToken() },
        // 上传的地址
        url: process.env.VUE_APP_BASE_API + "/system/contract/importData",
        ruleList: [],
        fileList: [],
        unitId: '',
        startTime: '',
        endTime: ''
      },
      dialogImageUrl: '',
      dialogVisible: false,
      disabled: false,
      props: {
        row: {

        }
      },
      unitList: [],
      deptList: [],
      activeNames: ['1'],
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 【请填写功能名称】表格数据
      contractList: [],
      // 弹出层标题
      title: "",
      // 详情标题
      detailName: "",
      // 是否显示弹出层
      open: false,
      // 是否显示详情
      detail: false,
      ruleData: [],
      // 表单参数
      form: {
      },
      // 表单校验
      rules: {
        name: [
          { required: true, message: "合同名称不能为空", trigger: "blur" }
        ],
        unitId: [
          { required: true, message: "运维单位不能为空", trigger: "change" }
        ],
        timezone: [
          { type: "array", required: true, message: "合同时间不能为空", trigger: "change" }
        ],
        ruleList: [
          { type: "array", required: true, message: "考核结果应用规则不能为空", trigger: "submit" }
        ]
      }
    };
  },
  created() {
    this.getList();
    this.selectUnit();
    this.selectDept();
  },
  methods: {
    addRule() {
      this.upload.ruleList.push({
        scoreCondition: '',
        description: ''
      });
    },
    deleteRule(index) {
      this.upload.ruleList.splice(index, 1);
    },
    submitForm() {
      updateContract(this.form).then(response => {
        this.detail = false;
        if (response.code != 200) {
          this.$message.error("操作失败");
        } else {
          this.$message.success("操作成功");
        }
      });
    },
    /** 导入按钮操作 */
    handleImport() {
      this.upload.title = "合同导入";
      this.upload.open = true;
    },
    /** 下载模板操作 */
    importTemplate() {
      this.download('system/contract/importTemplate', {
      }, `合同导入模板.xlsx`)
    },
    // 文件上传中处理
    handleFileUploadProgress(event, file, fileList) {
      this.upload.isUploading = true;
    },
    // 文件上传成功处理
    handleFileSuccess(response, file, fileList) {
      this.upload.open = false;
      this.upload.isUploading = false;
      this.$refs.upload.clearFiles();
      if (response.code != 200) {
        this.$message.warning(response.msg);
      } else {
        this.$message.success(response.msg);
      }
      this.getList();
    },
    // 提交上传文件
    submitFileForm() {
      let that = this;
      this.$refs["form"].validate(valid => {
        if (valid) {
          addContract(this.upload).then (response => {
            if (response.code != 200) {
              this.$message.error("操作失败");
            } else {
              this.$message.success("操作成功");
            }
          });
          // that.$refs.upload.submit();
        }
      })
    },
    // 时间选择发生变化
    dateChange() {
      this.upload.startTime = this.upload.timezone[0];
      this.upload.endTime = this.upload.timezone[1];
    },
    handleRemove(file) {
      console.log(file);
    },
    handlePictureCardPreview(file) {
      this.dialogImageUrl = file.url;
      this.dialogVisible = true;
    },
    // 运维公司下拉数据
    selectUnit() {
      unitSelect().then(res => {
        this.unitList = res.data;
      })
    },
    // 公安部门下拉数据
    selectDept() {
      deptSelect().then(res => {
        this.deptList = res.data;
      })
    },
    /** 查询【请填写功能名称】列表 */
    getList() {
      this.loading = true;
      listContract(this.queryParams).then(response => {
        this.contractList = response;
        this.total = response.total;
        this.loading = false;
      });
    },
    /** 获取合同规则 */
    getRuleList(item) {
      getRuleListByContractId(item.id).then(response => {
        this.ruleData = response.data;
        this.form.id = item.id;
        this.contractInfo = item;
      });
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加合同";
    },
    /** 详情按钮操作 */
    handleDetail(item) {
      this.detail = true;
      this.detailName = item.name;
      this.getRuleList(item);
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getContract(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改合同";
      });
    },
    /** 下载按钮操作 */
    handleDownload (data) {
      this.$download.resource(data);
    }
  }
};
</script>

<style scoped>
.table-expand {
  font-size: 0;
}

.table-expand {
  width: 100%;
  color: #99a9bf;
}

.inline-input-container {
  white-space: nowrap;
  /* 防止内容内部的换行 */
  margin-right: 50px;
  /* 可选的，用于在元素之间添加一些间距 */
  width: 7%;
}

.time {
  font-size: 13px;
  color: #999;
}

.bottom {
  margin-top: 13px;
  line-height: 12px;
}

.button {
  padding: 0;
  float: right;
}

.image {
  width: 100%;
  display: block;
}

.clearfix:before,
.clearfix:after {
  display: table;
  content: "";
}

.clearfix:after {
  clear: both
}

.top {
  display: block;
  margin-top: 10px;
}
</style>
<style scoped>
.margin-5 {
  margin-left: 5px;
}
.row-warp {
  display: flex;
  flex-direction: column;
}
.row {
  display: flex;
  flex-direction: row;
  align-items: center;
  justify-content: center;
  margin: 5px 0;
}
.row-left {
  flex: 1;
  display: flex;
  flex-direction: row;
}
.row-right {
  flex: 1;
  display: flex;
  flex-direction: row;
}
</style>
<style>
.el-cascader-node {
  max-width: 300px;
}
.el-divider--horizontal {
  margin-top: 50px;
  margin-bottom: 50px;
}
</style>
